@@ -1,5 +1,6 @@
 ### Credits:
 ### http://mathematicalcoffee.blogspot.nl/2014/06/ggpie-pie-graphs-in-ggplot2.html
+
 ggPie <- function (vector) {
   dat <- data.frame(table(vector));
   names(dat) <- c('labels', 'totals');
@@ -7,13 +8,15 @@ ggPie <- function (vector) {
   by = 'labels';  
   return(ggplot(dat, aes_string(x=factor(1), y=totals, fill=by)) +
            geom_bar(stat='identity', color='black') +
-           guides(fill=guide_legend(override.aes=list(colour=NA))) + # removes black borders from legend
+           # removes black borders from legend
+           guides(fill=guide_legend(override.aes=list(color=NA))) +
            coord_polar(theta='y') +
+           scale_y_continuous(breaks=cumsum(dat[[totals]]) - dat[[totals]] / 2,
+                              labels=dat[[by]]) +
            theme(axis.ticks=element_blank(),
                  axis.text.y=element_blank(),
-                 axis.text.x=element_text(colour='black'),
+                 axis.text.x=element_text(color='black'),
                  axis.title=element_blank(),
-                 legend.position="none") +
-           scale_y_continuous(breaks=cumsum(dat[[totals]]) - dat[[totals]] / 2, labels=dat[[by]]) +
-           theme(panel.background = element_rect(fill = "white")));
-}
\ No newline at end of file
+                 legend.position="none",
+                 panel.background = element_rect(fill = "white")));
+}
