@@ -1,15 +1,22 @@
 meansDiamondPlot <- function(dat, items = NULL, labels = NULL,
                              decreasing=NULL,
                              conf.level=.95,
-                             showData = TRUE, dataAlpha = .1, dataSize=1,
+                             showData = TRUE, dataAlpha = .1, dataSize=3,
                              dataColor = "#444444",
                              diamondColors = NULL,
                              jitterWidth = .5,
                              jitterHeight = .4,
                              returnLayerOnly = FALSE,
-                             xlab='Effect size estimate',
-                             theme=theme_bw(),
+                             xlab='Scores and means',
                              ylab=NULL,
+                             theme=theme_bw(),
+                             xbreaks = "auto",
+                             outputFile = NULL,
+                             outputWidth = 10,
+                             outputHeight = 10,
+                             ggsaveParams = list(units='cm',
+                                                 dpi=300,
+                                                 type="cairo"),
                              ...) {
 
   res <- list();
@@ -38,9 +45,11 @@ meansDiamondPlot <- function(dat, items = NULL, labels = NULL,
   if (showData) {
     plot <- plot +
       rawDataDiamondLayer(dat, items=items,
+                          itemOrder = res$intermediate$dat$rownr,
+                          dataAlpha=dataAlpha,
+                          dataColor=dataColor,
                           jitterWidth = jitterWidth,
                           jitterHeight = jitterHeight,
-                          itemOrder = res$intermediate$dat$rownr,
                           size=dataSize);
   }
 
@@ -51,6 +60,23 @@ meansDiamondPlot <- function(dat, items = NULL, labels = NULL,
     theme + ylab(ylab) + xlab(xlab) +
     theme(panel.grid.minor.y=element_blank());
 
+  if (!is.null(xbreaks) &&
+      length(xbreaks) == 1 &&
+      tolower(xbreaks) == "auto") {
+    plot <- plot + scale_x_continuous(breaks=sort(unique(unlist(dat[, items]))));
+  } else if (is.numeric(xbreaks)) {
+    plot <- plot + scale_x_continuous(breaks=xbreaks);
+  }
+  
+  if (!is.null(outputFile)) {
+    ggsaveParameters <- c(list(filename = outputFile,
+                               plot = plot,
+                               width = outputWidth,
+                               height = outputHeight),
+                          ggsaveParams);
+    do.call(ggsave, ggsaveParameters);
+  }
+  
   attr(plot, 'itemOrder') <- res$intermediate$dat$rownr;
 
   return(plot);
