@@ -11,81 +11,6 @@
 ###########################################################
 ###########################################################
 
-### This function generates a confidence level for a standard deviation
-### http://www.graphpad.com/guides/prism/6/statistics/index.htm?stat_confidence_interval_of_a_stand.htm
-### https://www.wolframalpha.com/input/?i=confidence+interval+for+a+standard+deviation&lk=3
-sdConfInt <- function(vector=NULL, sd=NULL, n=NULL, conf.level=.95) {
-  if (is.null(sd) & is.null(n)) {
-    if (is.null(vector)) {
-      stop("Please specify either vector, or sd and n!");
-    }
-    sd <- sd(vector);
-    n <- length(vector);
-  }
-  res <- list();
-  res$input <- list(vector=vector, sd=sd, n=n, conf.level=conf.level);
-  res$intermediate <- list(alpha = 1-conf.level);
-  res$intermediate$chisq.bound.lo <- qchisq(((1-res$intermediate$alpha)/2), n-1);
-  res$intermediate$chisq.bound.hi <- qchisq(res$intermediate$alpha/2, n-1);
-  ci.lo <- sqrt(((n-1)*sd^2)/res$intermediate$chisq.bound.lo);
-  ci.hi <- sqrt(((n-1)*sd^2)/res$intermediate$chisq.bound.hi);
-  res$output <- list(ci = c(ci.lo, ci.hi));
-  class(res) <- 'sdConfInt';
-  return(res);
-}
-
-print.sdConfInt <- function(x, digits=2, ...) {
-  print(x$output$ci, digits=digits, ...);
-}
-
-### This function generates a confidence level for a single mean
-meanConfInt <- function(vector=NULL, mean=NULL, sd=NULL, n=NULL, se=NULL, conf.level=.95) {
-  if (is.null(mean) & is.null(sd) & is.null(n) & is.null(se)) {
-    if (is.null(vector)) {
-      stop("Please specify either vector, or a mean and then also either sd and n or se!");
-    }
-    mean <- mean(vector);
-    sd <- sd(vector);
-    n <- length(vector);
-    se <- sd/sqrt(n);
-  }
-  else if (!is.null(mean) & !is.null(sd) & !is.null(n)) {
-    se <- sd/sqrt(n);
-  }
-  else if (is.null(mean) | is.null(se)) {
-    stop("Please specify either vector, or a mean and then also either sd and n or se!");
-  }
-    
-  res <- list();
-  res$input <- list(vector=vector, mean=mean, sd=sd, n=n, se=se, conf.level=conf.level);
-  res$intermediate <- list(alpha = 1-conf.level);
-  res$intermediate$t.bound.lo <- qt(res$intermediate$alpha/2, df=n-1);
-  res$intermediate$t.bound.hi <- qt(1-res$intermediate$alpha/2, df=n-1);
-  ci.lo <- mean + res$intermediate$t.bound.lo * se;
-  ci.hi <- mean + res$intermediate$t.bound.hi * se;
-  res$output <- list(ci = c(ci.lo, ci.hi));
-  class(res) <- 'meanConfInt';
-  return(res);
-}
-
-print.meanConfInt <- function(x, digits=2, ...) {
-  print(x$output$ci, digits=digits, ...);
-}
-
-### This function actually makes the scales
-makeScales <- function(dat, scales) {
-  for (currentScale in 1:length(scales)) {
-    if (length(unlist(scales[currentScale])) > 1) {
-      dat[[names(scales[currentScale])]] <-
-        rowMeans(dat[, unlist(scales[currentScale])], na.rm=TRUE);
-    }
-    else if (length(unlist(scales[currentScale])) == 1) {
-      dat[[names(scales[currentScale])]] <- dat[[unlist(scales[currentScale])]];
-    }
-  }
-  return(dat);
-}
-
 ### This function generates a pdf file with a report
 ### describing the variables.
 scaleInspection <- function(dat, items=NULL,
